@@ -11,6 +11,19 @@ cd build
       -DLLVM_USE_INTEL_JITEVENTS=ON
 "
 
+conditional_args="
+      -DLIBCXX_CXX_ABI=libcxxabi \
+      -DLIBCXX_CXX_ABI_INCLUDE_PATHS=${CONDA_BUILD_SYSROOT}/usr/include \
+      -DLIBCXX_CXX_ABI_LIBRARY_PATH=${CONDA_BUILD_SYSROOT}/usr/lib \
+      -DLLVM_INCLUDE_DOCS=OFF
+"
+
+if [[ $(uname) == Darwin ]]; then
+      conditional_args+="\
+      -DCMAKE_C_FLAGS='-mlinker-version=305' \
+      -DCMAKE_CXX_FLAGS='-mlinker-version=305'"
+fi
+
 cmake -DCMAKE_INSTALL_PREFIX="${PREFIX}" \
       -DCMAKE_BUILD_TYPE=Release \
       -DLLVM_ENABLE_RTTI=ON \
@@ -18,7 +31,7 @@ cmake -DCMAKE_INSTALL_PREFIX="${PREFIX}" \
       -DLLVM_INCLUDE_GO_TESTS=OFF \
       -DLLVM_INCLUDE_UTILS=ON \
       -DLLVM_INSTALL_UTILS=ON \
-      -DLLVM_UTILS_INSTALL_DIR=$SRC_DIR/install-utils \
+      -DLLVM_UTILS_INSTALL_DIR=libexec/llvm \
       -DLLVM_INCLUDE_DOCS=OFF \
       -DLLVM_INCLUDE_EXAMPLES=OFF \
       -DLLVM_ENABLE_TERMINFO=OFF \
